@@ -11,7 +11,8 @@ from .decorator import (
     useRunInThread,
     useCatchError,
     useExceptDebug,
-    useListify
+    useListify,
+    useCachedProperty,
 )
 from .utils import (
     useTimer,
@@ -24,8 +25,12 @@ from .utils import (
     useCookieToDict,
     useHeadersToDict
 )
+from .utils import useIs, useTo
+
 from ._datetime import useDateTime
 
+from ._path import usePath
+
 __all__ = [
     # data
     'useDict',
@@ -41,6 +46,8 @@ __all__ = [
     'useExceptDebug',
     'useListify',
     # utils
+    'useIs',
+    'useTo',
     'useTimer',
     'useTimerManager',
     'useUserAgent',
@@ -51,5 +58,6 @@ __all__ = [
     'useCookieToDict',
     'useHeadersToDict',
 
-    'useDateTime'
+    'useDateTime',
+    'usePath'
 ]
