@@ -1,7 +1,7 @@
 from . import useragent as useUserAgent
 from .timer import Timer as useTimer, TimerManager as useTimerManager
 from .import_object import import_object as useImport, LazyImport as useLazyImport
-from .to_dict import (
+from ._to import (
     cookie_to_dict as useCookieToDict,
     headers_to_dict as useHeadersToDict,
     data_to_dict as useDataToDict,
@@ -9,3 +9,5 @@ from .to_dict import (
 from .utils import (
     gen_unique_id as useUniqueId,
 )
+from . import _to as useTo
+from . import _is as useIs
